==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ItemHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ItemHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76f048177657ef44 javax_swing_plaf_basic_BasicComboPopup__24ItemHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_java_awt_event_ItemEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods {
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_java_awt_event_ItemEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ItemHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ItemHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ItemHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76f048177657ef44 javax_swing_plaf_basic_BasicComboPopup__24ItemHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods {
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ItemHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ItemHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ItemHandler_H_ */
